Hey guys, i’m rendering out an animation and have a slight issue.
When I render a single frame, it takes about ~5 minutes, yet when I render the animation (using precalcs!) the render time per frame has gone up to around 10 to 15 minutes per image. Common sense dictates that it should be quicker when rendering using precalcs, any ideas why it is rendering slower?
The irradiance map is fairly large (250mb) but surely this shouldn’t slow it down that much. Surely it should be quicker as it isn’t having to calculate it on every frame?!
is it possible to have too much detail in an irradiance map? Is there perhaps a way of filtering it at rendertime so that not every sample is used, etc? I’m clutching at straws here because I’m totally out of time on this and really need a solution fast.
Would adjusting the sample-lookup function make a difference at rendertime on a precomputed irradiance map, or is this calculated during the irradiance map calculation?
Well, it hasn’t made much difference at all. I simply don’t know why an animation with pre computed irriadiance & light cache is going slower (per frame) than rendering it without any precalcs.
the pre-calc setup was the same as the single test frame, except set up as a multiframe incrimental. I did it every 5 frames, so there is plenty of detail there considering the only thing moving is the camera.
We have similar problem here in Red Vertex when the motion blur is on. Rendering the frame with montion blur on workstation is ok but when we send it to the Backburner it starts to render several times slower.
Unfortunately i can’t reproduce this with simple scene setup.
It will be best if you could supply a scene to test with. Also the exact 3DS Max version and V-Ray that you are using.